aboutsummaryrefslogtreecommitdiff
path: root/reproduce/software
diff options
context:
space:
mode:
Diffstat (limited to 'reproduce/software')
-rwxr-xr-xreproduce/software/bash/configure.sh20
-rw-r--r--reproduce/software/config/installation/LOCAL.conf.in (renamed from reproduce/software/config/installation/LOCAL.mk.in)0
-rw-r--r--reproduce/software/config/installation/TARGETS.conf (renamed from reproduce/software/config/installation/TARGETS.mk)6
-rw-r--r--reproduce/software/config/installation/checksums.conf (renamed from reproduce/software/config/installation/checksums.mk)6
-rw-r--r--reproduce/software/config/installation/texlive-packages.conf (renamed from reproduce/software/config/installation/texlive.mk)0
-rw-r--r--reproduce/software/config/installation/versions.conf (renamed from reproduce/software/config/installation/versions.mk)6
-rw-r--r--reproduce/software/make/basic.mk6
-rw-r--r--reproduce/software/make/build-rules.mk4
-rw-r--r--reproduce/software/make/high-level.mk14
9 files changed, 31 insertions, 31 deletions
diff --git a/reproduce/software/config/installation/LOCAL.mk.in b/reproduce/software/config/installation/LOCAL.conf.in
index 1045f72..1045f72 100644
--- a/reproduce/software/config/installation/LOCAL.mk.in
+++ b/reproduce/software/config/installation/LOCAL.conf.in
diff --git a/reproduce/software/config/installation/TARGETS.mk b/reproduce/software/config/installation/TARGETS.conf
index 164d606..d2d5e2c 100644
--- a/reproduce/software/config/installation/TARGETS.mk
+++ b/reproduce/software/config/installation/TARGETS.conf
@@ -18,17 +18,17 @@
# All software that are currently available for installation can be seen in
# the following file.
#
-# reproduce/software/config/installation/versions.mk
+# reproduce/software/config/installation/versions.conf
#
# Please add any software that you need for your project in the respective
-# part below (using its name in `versions.mk', but without the `-version'
+# part below (using its name in `versions.conf', but without the `-version'
# part). Just note that if a program/library is a dependency of another,
# you don't need to include it here (it will be installed before the
# higher-level software anyway).
#
# Note that many low-level software will be installed before those that are
# installed in this step. They are clearly distinguished from the
-# higher-level (optional) software in `versions.mk'. These low-level
+# higher-level (optional) software in `versions.conf'. These low-level
# software MUST NOT be added here.
diff --git a/reproduce/software/config/installation/checksums.mk b/reproduce/software/config/installation/checksums.conf
index 28980e1..406ec1b 100644
--- a/reproduce/software/config/installation/checksums.mk
+++ b/reproduce/software/config/installation/checksums.conf
@@ -71,9 +71,9 @@ zlib-checksum = 73fd3fff4adeccd4894084c15ddac89890cd10ef105dd5e1835e1e9bbb6a49ff
# ------------------------------------------
#
# These are programs and libraries that are optional, The ones in
-# `reproduce/software/config/installation/TARGETS.mk' will be built as part
-# of a project. To specify a software there, just remove the `-checksum'
-# suffix from the list below.
+# `reproduce/software/config/installation/TARGETS.conf' will be built as
+# part of a project. To specify a software there, just remove the
+# `-checksum' suffix from the list below.
apachelog4cxx-checksum = aa59ce549c2c5cbeec031361dfce09cdfc3e62ee3bc9ecbc809507b7ec878c14409b98536b7d13c27690809c8e9d5ebafc3589c9fb5e4aecd5cc064943ae7d6b
apr-checksum = daa140c83c7e2c45c3980d9dc81d34fa662bebd050653562c39572d0ddf2eaedb71767c518a59d77f59db9b32e00221ef48b9f72ec3666c4521dd511969f3706
apr-util-checksum = 84da76e9b64da2de0996d4d6f3ab3f23db3724eb6352d218e0e8196bcc0b0a5d4fe791f41b4cc350ce3d04cce3bb3cf8bfb513d777d0cd030928368e6b55a536
diff --git a/reproduce/software/config/installation/texlive.mk b/reproduce/software/config/installation/texlive-packages.conf
index c53e170..c53e170 100644
--- a/reproduce/software/config/installation/texlive.mk
+++ b/reproduce/software/config/installation/texlive-packages.conf
diff --git a/reproduce/software/config/installation/versions.mk b/reproduce/software/config/installation/versions.conf
index 348a61c..565f1a4 100644
--- a/reproduce/software/config/installation/versions.mk
+++ b/reproduce/software/config/installation/versions.conf
@@ -69,9 +69,9 @@ zlib-version = 1.2.11
# ------------------------------------------
#
# These are programs and libraries that are optional, The ones in
-# `reproduce/software/config/installation/TARGETS.mk' will be built as part
-# of a project. To specify a software there, just remove the `-version'
-# suffix from the list below.
+# `reproduce/software/config/installation/TARGETS.conf' will be built as
+# part of a project. To specify a software there, just remove the
+# `-version' suffix from the list below.
apachelog4cxx-version = 0.10.0-603-014954db
apr-version = 1.7.0
apr-util-version = 1.6.1
diff --git a/reproduce/software/make/basic.mk b/reproduce/software/make/basic.mk
index 343b3b0..93dcdc2 100644
--- a/reproduce/software/make/basic.mk
+++ b/reproduce/software/make/basic.mk
@@ -34,9 +34,9 @@
# Top level environment
include reproduce/software/make/build-rules.mk
-include reproduce/software/config/installation/LOCAL.mk
-include reproduce/software/config/installation/versions.mk
-include reproduce/software/config/installation/checksums.mk
+include reproduce/software/config/installation/LOCAL.conf
+include reproduce/software/config/installation/versions.conf
+include reproduce/software/config/installation/checksums.conf
lockdir = $(BDIR)/locks
tdir = $(BDIR)/software/tarballs
diff --git a/reproduce/software/make/build-rules.mk b/reproduce/software/make/build-rules.mk
index cbde70b..f3ca7d2 100644
--- a/reproduce/software/make/build-rules.mk
+++ b/reproduce/software/make/build-rules.mk
@@ -1,7 +1,7 @@
# Generic configurable recipes to build packages with GNU Build system or
# CMake. This is Makefile is not intended to be run directly, it will be
-# imported into `dependencies-basic.mk' and `dependencies.mk'. They should
-# be activated with Make's `Call' function.
+# imported into `basic.mk' and `high-level.mk'. They should be activated
+# with Make's `Call' function.
#
# Copyright (C) 2018-2020 Mohammad Akhlaghi <mohammad@akhlaghi.org>
#
diff --git a/reproduce/software/make/high-level.mk b/reproduce/software/make/high-level.mk
index 0afeaba..bc77dab 100644
--- a/reproduce/software/make/high-level.mk
+++ b/reproduce/software/make/high-level.mk
@@ -28,11 +28,11 @@
# Top level environment
include reproduce/software/make/build-rules.mk
-include reproduce/software/config/installation/LOCAL.mk
-include reproduce/software/config/installation/TARGETS.mk
-include reproduce/software/config/installation/texlive.mk
-include reproduce/software/config/installation/versions.mk
-include reproduce/software/config/installation/checksums.mk
+include reproduce/software/config/installation/LOCAL.conf
+include reproduce/software/config/installation/TARGETS.conf
+include reproduce/software/config/installation/versions.conf
+include reproduce/software/config/installation/checksums.conf
+include reproduce/software/config/installation/texlive-packages.conf
lockdir = $(BDIR)/locks
tdir = $(BDIR)/software/tarballs
@@ -588,7 +588,7 @@ $(ibidir)/hdf5: $(ibidir)/openmpi \
# HEALPix includes the source of its C, C++, Python (and several other
# languages) libraries within one tarball. We will include the Python
# installation only when any other Python module is requested (in
-# `TARGETS.mk').
+# `TARGETS.conf').
#
# Note that the default `./configure' script is an interactive script which
# is hard to automate. So we need to go into the `autotools' directory of
@@ -1191,7 +1191,7 @@ $(itidir)/texlive-ready-tlmgr: reproduce/software/config/installation/texlive.co
#else
#forbiber = $(ibidir)/libnsl
#endif
-$(itidir)/texlive: reproduce/software/config/installation/texlive.mk \
+$(itidir)/texlive: reproduce/software/config/installation/texlive-packages.conf \
$(itidir)/texlive-ready-tlmgr \
$(forbiber)
diff --git a/reproduce/software/bash/configure.sh b/reproduce/software/bash/configure.sh
index 8cdd744..c681298 100755
--- a/reproduce/software/bash/configure.sh
+++ b/reproduce/software/bash/configure.sh
@@ -38,11 +38,11 @@ cdir=reproduce/software/config
sbdir=$cdir/installation
-pconf=$sbdir/LOCAL.mk
-ptconf=$sbdir/LOCAL_tmp.mk
-poconf=$sbdir/LOCAL_old.mk
-depverfile=$cdir/installation/versions.mk
-depshafile=$cdir/installation/checksums.mk
+pconf=$sbdir/LOCAL.conf
+ptconf=$sbdir/LOCAL_tmp.conf
+poconf=$sbdir/LOCAL_old.conf
+depverfile=$cdir/installation/versions.conf
+depshafile=$cdir/installation/checksums.conf
# --------- Delete for no Gnuastro ---------
glconf=$cdir/gnuastro/gnuastro-local.conf
# ------------------------------------------
@@ -117,7 +117,7 @@ EOF
# What to do with possibly existing configuration file
# ----------------------------------------------------
#
# `LOCAL.mk' is the top-most local configuration for the project. If it
# already exists when this script is run, we'll make a copy of it as backup
# (for example the user might have ran `./project configure' by mistake).
printnotice=yes
@@ -299,10 +299,10 @@ if [ x"$input_dir" = x ]; then
else
indir=$input_dir
fi
-wfpc2name=$(awk '!/^#/ && $1=="WFPC2IMAGE" {print $3}' $adir/INPUTS.mk)
-wfpc2md5=$(awk '!/^#/ && $1=="WFPC2MD5" {print $3}' $adir/INPUTS.mk)
-wfpc2size=$(awk '!/^#/ && $1=="WFPC2SIZE" {print $3}' $adir/INPUTS.mk)
-wfpc2url=$(awk '!/^#/ && $1=="WFPC2URL" {print $3}' $adir/INPUTS.mk)
+wfpc2name=$(awk '!/^#/ && $1=="WFPC2IMAGE" {print $3}' $adir/INPUTS.conf)
+wfpc2md5=$(awk '!/^#/ && $1=="WFPC2MD5" {print $3}' $adir/INPUTS.conf)
+wfpc2size=$(awk '!/^#/ && $1=="WFPC2SIZE" {print $3}' $adir/INPUTS.conf)
+wfpc2url=$(awk '!/^#/ && $1=="WFPC2URL" {print $3}' $adir/INPUTS.conf)
if [ $rewritepconfig = yes ] && [ x"$input_dir" = x ]; then
cat <<EOF
@@ -117,7 +117,7 @@ EOF
# ----------------------------------------------------
#
-# `LOCAL.mk' is the top-most local configuration for the project. If it
+# `LOCAL.conf' is the top-most local configuration for the project. If it
# already exists when this script is run, we'll make a copy of it as backup
# (for example the user might have ran `./project configure' by mistake).